@@ -2041,3 +2041,64 @@ write_ret:
   retc->x.i_val = rc;
   return retc;
 }
+
+/*
+ * NASL NETCONF
+ */
+/**
+ * @brief Excecute the NETCONF subsystem on the the ssh channel
+ *
+ * @naslfn{ssh_execute_netconf_subsystem}
+ * @nasluparam
+ * - An SSH session id.
+ * @naslret An int on success or NULL on error.
+ *
+ * @param[in] lexic Lexical context of NASL interpreter.
+ * @return Session ID on success, NULL on failure.
+ */
+tree_cell *
+nasl_ssh_execute_netconf_subsystem (lex_ctxt *lexic)
+{
+  int tbl_slot, session_id;
+  ssh_channel channel;
+  ssh_session session;
+  tree_cell *retc;
+
+  session_id = get_int_var_by_num (lexic, 0, -1);
+
+  if (!verify_session_id (session_id, "ssh_execute_netconf_subsystem",
+                          &tbl_slot, lexic))
+    return NULL;
+  session = session_table[tbl_slot].session;
+  channel = ssh_channel_new (session);
+  if (!channel)
+    return NULL;
+
+  if (ssh_channel_open_session (channel))
+    {
+      /* FIXME: Handle SSH_AGAIN.  */
+      g_message ("ssh_channel_open_session failed: %s",
+                 ssh_get_error (session));
+      ssh_channel_free (channel);
+      retc = alloc_typed_cell (CONST_INT);
+      retc->x.i_val = SSH_ERROR;
+      return retc;
+    }
+
+  int err;
+  if ((err = ssh_channel_request_subsystem (channel, "netconf")) < 0)
+    {
+      g_message ("%s Could not execute netconf subsystem", __func__);
+      retc = alloc_typed_cell (CONST_INT);
+      retc->x.i_val = err;
+      return retc;
+    }
+
+  if (session_table[tbl_slot].channel)
+    ssh_channel_free (session_table[tbl_slot].channel);
+  session_table[tbl_slot].channel = channel;
+
+  retc = alloc_typed_cell (CONST_INT);
+  retc->x.i_val = session_table[tbl_slot].session_id;
+  return retc;
+}
