@@ -39,6 +39,12 @@ impl<'a> ArgsStruct<'a> {
             .any(|arg| matches!(arg.kind, ArgKind::Register))
     }
 
+    fn has_script_ctx_arg(&self) -> bool {
+        self.args
+            .iter()
+            .any(|arg| matches!(arg.kind, ArgKind::ScriptCtx))
+    }
+
     fn get_args(&self) -> TokenStream {
         self
             .args.iter().map(|arg| {
@@ -80,9 +86,9 @@ impl<'a> ArgsStruct<'a> {
                             }
                         }
                     }
-                    ArgKind::Context => {
+                    ArgKind::ScanCtx => {
                         quote! {
-                            _context
+                            _scan_context
                         }
                     },
                     ArgKind::Register => {
@@ -93,15 +99,21 @@ impl<'a> ArgsStruct<'a> {
                     ArgKind::NaslSockets(arg) => {
                         if arg.mutable {
                             quote! {
-                                &mut *_context.write_sockets().await
+                                &mut *_scan_context.write_sockets().await
                             }
                         }
                         else {
                             quote! {
-                                &*_context.read_sockets().await
+                                &*_scan_context.read_sockets().await
                             }
                         }
                     },
+                    ArgKind::ScriptCtx => {
+                        quote! {
+                            _script_ctx
+                        }
+                    },
+
                     ArgKind::PositionalIterator(arg) => {
                         let position = arg.position;
                         quote! {
@@ -167,6 +179,9 @@ impl<'a> ArgsStruct<'a> {
         if self.has_register_arg() {
             return quote! {};
         }
+        if self.has_script_ctx_arg() {
+            return quote! {};
+        }
         let named_array = self.make_array_of_names(ArgKind::get_named_arg_name);
         let maybe_named_array = self.make_array_of_names(ArgKind::get_maybe_named_arg_name);
         let num_allowed_positional_args = if self.has_positional_iterator_arg() {
@@ -243,7 +258,8 @@ impl<'a> ArgsStruct<'a> {
         let inputs = quote! {
             #self_arg
             _register: &crate::nasl::Register,
-            _context: &crate::nasl::Context<'_>,
+            _scan_context: &crate::nasl::ScanCtx<'_>,
+            _script_ctx: &mut crate::nasl::ScriptCtx,
         };
         let output_ty = match output {
             syn::ReturnType::Default => quote! { () },
@@ -251,9 +267,9 @@ impl<'a> ArgsStruct<'a> {
         };
         let asyncness = sig.asyncness;
         let checks = self.gen_checks();
-        let mangled_ident_original_fn = Ident::new(&format!("_internal_{}", ident), ident.span());
+        let mangled_ident_original_fn = Ident::new(&format!("_internal_{ident}"), ident.span());
         let mangled_ident_transformed_fn =
-            Ident::new(&(format!("_internal_convert_{}", ident)), ident.span());
+            Ident::new(&(format!("_internal_convert_{ident}")), ident.span());
         let inner_call = self.get_inner_call_expr(&mangled_ident_original_fn, asyncness);
         let add_to_set = self.impl_add_to_set(ident, &mangled_ident_transformed_fn, asyncness);
 
