@@ -3,7 +3,8 @@ use std::collections::HashSet;
 use crate::error::{Error, ErrorKind, Result};
 use crate::types::*;
 use crate::utils::{
-    get_subty_if_name_is, ty_is_context, ty_is_nasl_sockets, ty_is_register, ty_name_is,
+    get_subty_if_name_is, ty_is_nasl_sockets, ty_is_register, ty_is_scan_ctx, ty_is_script_ctx,
+    ty_name_is,
 };
 use syn::punctuated::Punctuated;
 use syn::token::Comma;
@@ -39,12 +40,15 @@ impl Parse for Attr {
 
 impl Attrs {
     fn get_arg_kind(&self, ident: &Ident, position: usize, ty: &Type) -> ArgKind {
-        if ty_is_context(ty) {
-            return ArgKind::Context;
+        if ty_is_scan_ctx(ty) {
+            return ArgKind::ScanCtx;
         }
         if ty_is_register(ty) {
             return ArgKind::Register;
         }
+        if ty_is_script_ctx(ty) {
+            return ArgKind::ScriptCtx;
+        }
         if let Some(mutable) = ty_is_nasl_sockets(ty) {
             return ArgKind::NaslSockets(NaslSocketsArg { mutable });
         }
@@ -226,10 +230,10 @@ fn parse_function_args<'a>(
 fn first_unsorted_index(iter: impl Iterator<Item = usize>) -> Option<usize> {
     let mut prev = None;
     for (index, next) in iter.enumerate() {
-        if let Some(prev) = prev {
-            if next < prev {
-                return Some(index);
-            }
+        if let Some(prev) = prev
+            && next < prev
+        {
+            return Some(index);
         }
         prev = Some(next);
     }
