@@ -2,6 +2,11 @@
 //
 // SPDX-License-Identifier: GPL-2.0-or-later WITH x11vnc-openssl-exception
 
+// We allow this fow now, since it would require lots of changes
+// but should eventually solve this.
+#![allow(clippy::result_large_err)]
+#![allow(clippy::large_enum_variant)]
+
 #[cfg(feature = "nasl-builtin-raw-ip")]
 pub mod alive_test;
 pub mod feed;
