@@ -3,11 +3,7 @@
 // SPDX-License-Identifier: GPL-2.0-or-later WITH x11vnc-openssl-exception
 
 /// Configuration preference for the scanner
-#[derive(Default, Debug, Clone, PartialEq, Eq)]
-#[cfg_attr(
-    feature = "serde_support",
-    derive(serde::Serialize, serde::Deserialize)
-)]
+#[derive(Default, Debug, Clone, PartialEq, Eq, serde::Serialize, serde::Deserialize)]
 pub struct ScanPreference {
     /// The ID of a scan preference.
     pub id: String,
@@ -16,12 +12,8 @@ pub struct ScanPreference {
 }
 
 /// Preference value
-#[derive(Debug, Clone, PartialEq, Eq)]
-#[cfg_attr(
-    feature = "serde_support",
-    derive(serde::Serialize, serde::Deserialize),
-    serde(untagged)
-)]
+#[derive(Debug, Clone, PartialEq, Eq, serde::Serialize, serde::Deserialize)]
+#[serde(untagged)]
 pub enum PreferenceValue {
     Bool(bool),
     Int(i64),
@@ -35,11 +27,7 @@ impl Default for PreferenceValue {
 }
 
 /// Configuration preference information for a scan. The type can be derived from the default value.
-#[derive(Default, Debug, Clone, PartialEq, Eq)]
-#[cfg_attr(
-    feature = "serde_support",
-    derive(serde::Serialize, serde::Deserialize)
-)]
+#[derive(Debug, Clone, PartialEq, Eq, serde::Serialize, serde::Deserialize)]
 pub struct ScanPreferenceInformation {
     /// The ID of the scan preference
     pub id: &'static str,
