@@ -9,44 +9,36 @@ use super::{credential::Credential, port::Port};
 pub type Host = String;
 
 /// Information about a target of a scan
-#[derive(Default, Debug, Clone, PartialEq, Eq)]
-#[cfg_attr(
-    feature = "serde_support",
-    derive(serde::Serialize, serde::Deserialize)
-)]
+#[derive(Default, Debug, Clone, PartialEq, Eq, serde::Serialize, serde::Deserialize)]
 pub struct Target {
     /// List of hosts to scan
     pub hosts: Vec<Host>,
     /// List of ports used for scanning
     pub ports: Vec<Port>,
-    #[cfg_attr(feature = "serde_support", serde(default))]
+    #[serde(default)]
     /// List of excluded hosts to scan
     pub excluded_hosts: Vec<Host>,
-    #[cfg_attr(feature = "serde_support", serde(default))]
+    #[serde(default)]
     /// List of credentials used to get access to a system
     pub credentials: Vec<Credential>,
-    #[cfg_attr(feature = "serde_support", serde(default))]
+    #[serde(default)]
     /// List of ports used for alive testing
     pub alive_test_ports: Vec<Port>,
-    #[cfg_attr(feature = "serde_support", serde(default))]
+    #[serde(default)]
     /// Methods used for alive testing
     pub alive_test_methods: Vec<AliveTestMethods>,
-    #[cfg_attr(feature = "serde_support", serde(default))]
+    #[serde(default)]
     /// If multiple IP addresses resolve to the same DNS name the DNS name will only get scanned
     /// once.
     pub reverse_lookup_unify: Option<bool>,
-    #[cfg_attr(feature = "serde_support", serde(default))]
+    #[serde(default)]
     /// Only scan IP addresses that can be resolved into a DNS name.
     pub reverse_lookup_only: Option<bool>,
 }
 
 /// Enum of possible alive test methods
-#[derive(Debug, Clone, PartialEq, Eq)]
-#[cfg_attr(
-    feature = "serde_support",
-    derive(serde::Serialize, serde::Deserialize)
-)]
-#[cfg_attr(feature = "serde_support", serde(rename_all = "snake_case"))]
+#[derive(Debug, Clone, PartialEq, Eq, serde::Serialize, serde::Deserialize)]
+#[serde(rename_all = "snake_case")]
 pub enum AliveTestMethods {
     TcpAck = 0x01,
     Icmp = 0x02,
@@ -79,11 +71,11 @@ impl TryFrom<u8> for AliveTestMethods {
 impl Display for AliveTestMethods {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match self {
-            AliveTestMethods::TcpAck => write!(f, "tcp_ack"),
+            AliveTestMethods::TcpAck => write!(f, "tcp_ping"),
             AliveTestMethods::Icmp => write!(f, "icmp"),
             AliveTestMethods::Arp => write!(f, "arp"),
             AliveTestMethods::ConsiderAlive => write!(f, "consider_alive"),
-            AliveTestMethods::TcpSyn => write!(f, "tcp_syn"),
+            AliveTestMethods::TcpSyn => write!(f, "tcp_ping"),
         }
     }
 }
