@@ -10,7 +10,7 @@ pub mod syntax;
 pub mod utils;
 
 #[cfg(test)]
-pub mod test_utils;
+mod test_utils;
 
 #[cfg(feature = "nasl-builtin-raw-ip")]
 pub mod raw_ip_utils {
@@ -20,16 +20,13 @@ pub mod raw_ip_utils {
 pub mod prelude {
     pub use super::builtin::BuiltinError;
     pub use super::code::Code;
-    pub use super::code::ParseResult;
     pub use super::interpreter::NaslValue;
     pub use super::interpreter::Register;
     pub use super::syntax::FSPluginLoader;
     pub use super::syntax::Loader;
     pub use super::utils::ArgumentError;
     pub use super::utils::FnError;
-    pub use super::utils::InternalError;
     pub use super::utils::NaslResult;
-    pub use super::utils::error::FnErrorKind;
     pub use super::utils::error::Retryable;
     pub use super::utils::error::ReturnValue;
     pub use super::utils::error::WithErrorInfo;
@@ -51,7 +48,7 @@ pub use builtin::nasl_std_functions;
 pub use syntax::NoOpLoader;
 
 #[cfg(test)]
-pub mod test_prelude {
+mod test_prelude {
     pub use super::prelude::*;
     pub use super::test_utils::DefaultTestBuilder;
     pub use super::test_utils::TestBuilder;
