@@ -68,7 +68,7 @@ pub struct Scanner {
 #[derive(Deserialize, Serialize, Debug, Clone)]
 pub enum ScannerType {
     #[serde(rename = "ospd")]
-    OSPD,
+    Ospd,
     #[serde(rename = "openvas")]
     Openvas,
     #[serde(rename = "openvasd")]
@@ -77,7 +77,7 @@ pub enum ScannerType {
 
 impl Default for ScannerType {
     fn default() -> Self {
-        Self::OSPD
+        Self::Ospd
     }
 }
 
@@ -91,7 +91,7 @@ impl TypedValueParser for ScannerType {
         value: &std::ffi::OsStr,
     ) -> Result<Self::Value, clap::Error> {
         Ok(match value.to_str().unwrap_or_default() {
-            "ospd" => ScannerType::OSPD,
+            "ospd" => ScannerType::Ospd,
             "openvas" => ScannerType::Openvas,
             "openvasd" => ScannerType::Openvasd,
             x => {
@@ -484,7 +484,7 @@ impl Config {
                     .env("SCANNER_TYPE")
                     .long("scanner-type")
                     .value_name("ospd,openvas")
-                    .value_parser(ScannerType::OSPD)
+                    .value_parser(ScannerType::Ospd)
                     .help("Type of scanner used to manage scans")
             )
             .arg(
