@@ -2,11 +2,14 @@
 //
 // SPDX-License-Identifier: GPL-2.0-or-later WITH x11vnc-openssl-exception
 
-use async_trait::async_trait;
-use scannerlib::{feed, nasl::FSPluginLoader, storage::inmemory::InMemoryStorage};
-use std::sync::{Arc, RwLock};
-
 use crate::{config, notus::NotusWrapper, response, scheduling, tls::TlsConfig};
+use async_trait::async_trait;
+use scannerlib::{
+    feed, nasl::FSPluginLoader, scanner::preferences::preference,
+    storage::inmemory::InMemoryStorage,
+};
+use std::collections::HashMap;
+use std::sync::{Arc, RwLock};
 
 use scannerlib::models::scanner::{
     Error, ScanDeleter, ScanResultFetcher, ScanResults, ScanStarter, ScanStopper,
@@ -32,6 +35,7 @@ pub struct ContextBuilder<S, DB, T> {
     scheduler_config: Option<config::Scheduler>,
     mode: config::Mode,
     enable_get_performance: bool,
+    preferences: Option<preference::FullScanPreferences>,
 }
 
 impl<S>
@@ -52,6 +56,7 @@ impl<S>
             scheduler_config: None,
             mode: config::Mode::default(),
             enable_get_performance: false,
+            preferences: None,
         }
     }
 }
@@ -88,6 +93,14 @@ impl<S, DB, T> ContextBuilder<S, DB, T> {
         self
     }
 
+    /// Set scanner preferences
+    pub fn scan_preferences(mut self, prefs: HashMap<String, preference::ScanPrefValue>) -> Self {
+        let mut prefs_bind = preference::FullScanPreferences::new();
+        prefs_bind.override_default_preferences(prefs);
+        self.preferences = Some(prefs_bind);
+        self
+    }
+
     /// Enables the GET /scans endpoint.
     pub fn enable_get_scans(mut self, enable: bool) -> Self {
         self.enable_get_scans = enable;
@@ -126,6 +139,7 @@ impl<S, DB, T> ContextBuilder<S, DB, T> {
             scheduler_config,
             mode,
             enable_get_performance,
+            preferences,
         } = self;
         ContextBuilder {
             scanner,
@@ -140,6 +154,7 @@ impl<S, DB, T> ContextBuilder<S, DB, T> {
             scheduler_config,
             mode,
             enable_get_performance,
+            preferences,
         }
     }
 }
@@ -163,6 +178,7 @@ impl<S, DB> ContextBuilder<S, DB, NoScanner> {
             scheduler_config,
             mode,
             enable_get_performance,
+            preferences,
         } = self;
         ContextBuilder {
             scanner: Scanner(scanner),
@@ -177,6 +193,7 @@ impl<S, DB> ContextBuilder<S, DB, NoScanner> {
             scheduler_config,
             mode,
             enable_get_performance,
+            preferences,
         }
     }
 }
@@ -228,6 +245,7 @@ impl<S, DB> ContextBuilder<S, DB, Scanner<S>> {
             enable_get_performance: self.enable_get_performance,
             notus: self.notus,
             mode: self.mode,
+            scan_preferences: self.preferences,
         }
     }
 }
@@ -258,6 +276,7 @@ pub struct Context<S, DB> {
     /// This allows us to throttle requests per need and gives us control when to start/stop/delete
     /// a scan.
     pub scheduler: scheduling::Scheduler<DB, S>,
+    pub scan_preferences: Option<preference::FullScanPreferences>,
 }
 
 #[derive(Debug, Clone, Default)]
