@@ -265,7 +265,7 @@ impl From<Response> for Status {
 
 impl Response {
     /// Get the status of the response
-    pub fn status(self) -> Status {
+    fn status(self) -> Status {
         match self {
             Response::Failure { status } => status,
             Response::StartScan { status, .. } => status,
@@ -287,13 +287,6 @@ pub struct Status {
     pub code: StringU64,
 }
 
-impl Status {
-    /// Check if the status is OK
-    pub fn is_ok(&self) -> bool {
-        self.code.0 == 200
-    }
-}
-
 #[derive(Clone, Debug, Deserialize, PartialEq)]
 /// OSPD does rename openvas messages
 ///
@@ -396,7 +389,7 @@ struct HostDetail {
 }
 
 impl HostDetail {
-    pub fn extract(&self) -> Option<crate::models::Detail> {
+    fn extract(&self) -> Option<crate::models::Detail> {
         self.detail.first().cloned()
     }
 }
@@ -449,18 +442,6 @@ pub struct Results {
     pub result: Vec<ScanResult>,
 }
 
-impl Results {
-    /// Push a result to the results
-    pub fn push(&mut self, result: ScanResult) {
-        self.result.push(result);
-    }
-
-    /// Extend the results with another results
-    pub fn extend(&mut self, results: Results) {
-        self.result.extend(results.result);
-    }
-}
-
 impl From<Results> for Vec<crate::models::Result> {
     fn from(results: Results) -> Self {
         results
