@@ -2,13 +2,10 @@
 //
 // SPDX-License-Identifier: GPL-2.0-or-later WITH x11vnc-openssl-exception
 
-use std::sync::Arc;
-
 use crate::nasl::syntax::{FSPluginLoader, Loader};
 
 use crate::nasl::utils::scan_ctx::ContextStorage;
 use crate::scheduling::{ConcurrentVT, ConcurrentVTResult, SchedulerStorage, VTError};
-use crate::storage::inmemory::InMemoryStorage;
 
 pub trait Schedule: Iterator<Item = ConcurrentVTResult> + Sized {
     fn cache(self) -> Result<Vec<ConcurrentVT>, VTError> {
@@ -32,9 +29,6 @@ where
     type Loader = L;
 }
 
-/// The default scanner stack, consisting of `InMemoryStorage`,
-/// `FSPluginLoader` and `NaslFunctionRegister`.
-pub type DefaultScannerStack = (Arc<InMemoryStorage>, FSPluginLoader);
-
-/// Like `DefaultScannerStack` but with a specific storage type.
+/// A scanner stack, consisting of a generic storage type,
+/// and `FSPluginLoader`.
 pub type ScannerStackWithStorage<S> = (S, FSPluginLoader);
