@@ -37,7 +37,7 @@ use tracing_test::traced_test;
 
 type TestStack = (Arc<InMemoryStorage>, fn(&str) -> String);
 
-pub fn setup(scripts: &[(String, Nvt)]) -> (TestStack, Executor, Scan) {
+fn setup(scripts: &[(String, Nvt)]) -> (TestStack, Executor, Scan) {
     let storage = InMemoryStorage::new();
     scripts.iter().map(|(_, v)| v).for_each(|n| {
         storage
@@ -73,7 +73,7 @@ fn make_scanner_and_scan(scripts: &[(String, Nvt)]) -> (Scanner<TestStack>, Scan
     (Scanner::new(storage, loader, executor), scan)
 }
 
-pub fn only_success() -> [(String, Nvt); 3] {
+fn only_success() -> [(String, Nvt); 3] {
     [
         GenerateScript::with_dependencies("0", &[]).generate(),
         GenerateScript::with_dependencies("1", &["0.nasl"]).generate(),
@@ -88,7 +88,7 @@ fn loader(s: &str) -> String {
 }
 
 #[derive(Debug, Default)]
-pub struct GenerateScript {
+struct GenerateScript {
     pub id: String,
     pub rc: usize,
     pub dependencies: Vec<String>,
@@ -100,7 +100,7 @@ pub struct GenerateScript {
 }
 
 impl GenerateScript {
-    pub fn with_dependencies(id: &str, dependencies: &[&str]) -> GenerateScript {
+    fn with_dependencies(id: &str, dependencies: &[&str]) -> GenerateScript {
         let dependencies = dependencies.iter().map(|x| x.to_string()).collect();
 
         GenerateScript {
@@ -110,7 +110,7 @@ impl GenerateScript {
         }
     }
 
-    pub fn with_required_keys(id: &str, required_keys: &[&str]) -> GenerateScript {
+    fn with_required_keys(id: &str, required_keys: &[&str]) -> GenerateScript {
         let required_keys = required_keys.iter().map(|x| x.to_string()).collect();
         GenerateScript {
             id: id.to_string(),
@@ -119,7 +119,7 @@ impl GenerateScript {
         }
     }
 
-    pub fn with_mandatory_keys(id: &str, mandatory_keys: &[&str]) -> GenerateScript {
+    fn with_mandatory_keys(id: &str, mandatory_keys: &[&str]) -> GenerateScript {
         let mandatory_keys = mandatory_keys.iter().map(|x| x.to_string()).collect();
         GenerateScript {
             id: id.to_string(),
@@ -128,7 +128,7 @@ impl GenerateScript {
         }
     }
 
-    pub fn with_excluded_keys(id: &str, exclude_keys: &[&str]) -> GenerateScript {
+    fn with_excluded_keys(id: &str, exclude_keys: &[&str]) -> GenerateScript {
         let exclude = exclude_keys.iter().map(|x| x.to_string()).collect();
         GenerateScript {
             id: id.to_string(),
@@ -137,7 +137,7 @@ impl GenerateScript {
         }
     }
 
-    pub fn with_required_ports(id: &str, ports: &[(Protocol, &str)]) -> GenerateScript {
+    fn with_required_ports(id: &str, ports: &[(Protocol, &str)]) -> GenerateScript {
         let required_tcp_ports = ports
             .iter()
             .filter(|(p, _)| matches!(p, Protocol::TCP))
@@ -158,7 +158,7 @@ impl GenerateScript {
         }
     }
 
-    pub fn generate(&self) -> (String, Nvt) {
+    fn generate(&self) -> (String, Nvt) {
         let keys = |x: &[String]| -> String {
             x.iter().fold(String::default(), |acc, e| {
                 let acc = if acc.is_empty() {
