@@ -3,6 +3,7 @@
 // SPDX-License-Identifier: GPL-2.0-or-later WITH x11vnc-openssl-exception
 
 use std::{
+    collections::BTreeSet,
     fs::{self},
     path::{Path, PathBuf},
 };
@@ -11,19 +12,26 @@ use futures::StreamExt;
 use scannerlib::{
     feed,
     nasl::{
-        Context,
+        Code, Register, ScanCtx, ScanCtxBuilder,
+        error::{Level, emit_errors},
         interpreter::ForkingInterpreter,
         nasl_std_functions,
-        utils::{context::Target, error::ReturnBehavior},
+        utils::{
+            error::ReturnBehavior,
+            scan_ctx::{Ports, Target},
+        },
+    },
+    scanner::preferences::preference::ScanPrefs,
+    storage::{
+        ScanID,
+        items::{kb::KbContextKey, nvt::Oid},
     },
-    storage::{ScanID, items::nvt::Oid},
 };
-use scannerlib::{nasl::utils::context::ContextStorage, storage::inmemory::InMemoryStorage};
+use scannerlib::{nasl::utils::scan_ctx::ContextStorage, storage::inmemory::InMemoryStorage};
 use scannerlib::{
     nasl::{
-        ContextBuilder, FSPluginLoader, Loader, NaslValue, NoOpLoader, RegisterBuilder,
-        WithErrorInfo,
-        interpreter::InterpretErrorKind,
+        FSPluginLoader, Loader, NaslValue, WithErrorInfo,
+        interpreter::InterpreterErrorKind,
         syntax::{LoadError, load_non_utf8_path},
     },
     storage::items::nvt::Nvt,
@@ -31,7 +39,7 @@ use scannerlib::{
 
 use crate::{CliError, CliErrorKind, Db, Filename};
 
-fn load(ctx: &Context, script: &Path) -> Result<String, CliErrorKind> {
+fn load(ctx: &ScanCtx, script: &Path) -> Result<String, CliErrorKind> {
     match load_non_utf8_path(&script) {
         Ok(x) => Ok(x),
         Err(LoadError::NotFound(_)) => {
@@ -47,23 +55,31 @@ fn load(ctx: &Context, script: &Path) -> Result<String, CliErrorKind> {
     }
 }
 
-async fn run_with_context(context: Context<'_>, script: &Path) -> Result<(), CliErrorKind> {
-    let register = RegisterBuilder::build();
-    let code = load(&context, script)?;
-    let mut results = ForkingInterpreter::new(&code, register, &context).stream();
+async fn run_with_context(context: ScanCtx<'_>, script: &Path) -> Result<(), CliErrorKind> {
+    let register = Register::default();
+    let code = Code::from_string_filename(&load(&context, script)?, script);
+    let (ast, file) = code
+        .parse()
+        .emit_errors_get_ast_and_file()
+        .map_err(CliErrorKind::SyntaxError)?;
+    let mut results = ForkingInterpreter::new(ast, register, &context).stream();
     while let Some(result) = results.next().await {
         let r = match result {
             Ok(x) => x,
             Err(e) => {
-                if let InterpretErrorKind::FunctionCallError(ref fe) = e.kind {
+                if let InterpreterErrorKind::FunctionCallError(ref fe) = e.kind {
                     match fe.kind.return_behavior() {
-                        ReturnBehavior::ExitScript => return Err(e.into()),
+                        ReturnBehavior::ExitScript => {
+                            emit_errors(&file, std::iter::once(&e), Level::Error);
+                            return Err(e.into());
+                        }
                         ReturnBehavior::ReturnValue(val) => {
-                            tracing::warn!("{}", e.to_string());
+                            emit_errors(&file, std::iter::once(&e), Level::Warn);
                             val.clone()
                         }
                     }
                 } else {
+                    emit_errors(&file, std::iter::once(&e), Level::Error);
                     return Err(e.into());
                 }
             }
@@ -112,26 +128,53 @@ async fn run_on_storage<S: ContextStorage, L: Loader>(
     storage: S,
     loader: L,
     target: Target,
+    kb: Vec<String>,
+    ports: Ports,
     script: &Path,
+    scan_preferences: ScanPrefs,
 ) -> Result<(), CliErrorKind> {
     let scan_id = ScanID(format!("scannerctl-{}", script.to_string_lossy()));
     let filename = script;
-    let cb = ContextBuilder {
+    let kbctx = (
+        scan_id.clone(),
+        scannerlib::storage::Target(target.ip_addr().to_string()),
+    );
+    for s in kb.iter() {
+        match s.split_once("=") {
+            Some((k, v)) => {
+                let storage_ctx = KbContextKey(kbctx.clone(), k.into());
+                let _ = storage
+                    .dispatch(storage_ctx, v.into())
+                    .map_err(CliErrorKind::StorageError);
+            }
+            None => return Err(CliErrorKind::InvalidCmdOpt(s.to_string())),
+        }
+    }
+
+    let cb = ScanCtxBuilder {
         storage: &storage,
         loader: &loader,
         executor: &nasl_std_functions(),
         target,
+        ports,
         scan_id,
         filename,
+        scan_preferences,
+        alive_test_methods: Vec::new(),
     };
     run_with_context(cb.build(), script).await
 }
 
+#[allow(clippy::too_many_arguments)]
 pub async fn run(
     db: &Db,
     feed: Option<PathBuf>,
     script: &Path,
     target: Option<String>,
+    kb: Vec<String>,
+    tcp_ports: Vec<u16>,
+    udp_ports: Vec<u16>,
+    scan_preferences: ScanPrefs,
 ) -> Result<(), CliError> {
     let target = target
         .map(|target| {
@@ -139,13 +182,21 @@ pub async fn run(
                 .unwrap_or_else(|| panic!("Hostname resolution failed for target {target}"))
         })
         .unwrap_or(Target::localhost());
+    let ports = Ports {
+        tcp: BTreeSet::from_iter(tcp_ports.into_iter()),
+        udp: BTreeSet::from_iter(udp_ports.into_iter()),
+    };
+
     let result = match (db, feed) {
         (Db::InMemory, None) => {
             run_on_storage(
                 InMemoryStorage::default(),
-                NoOpLoader::default(),
+                FSPluginLoader::new(script.parent().unwrap()),
                 target,
+                kb,
+                ports,
                 script,
+                scan_preferences,
             )
             .await
         }
@@ -158,7 +209,7 @@ pub async fn run(
             } else {
                 load_feed_by_exec(&storage, &loader).await?
             }
-            run_on_storage(storage, loader, target, script).await
+            run_on_storage(storage, loader, target, kb, ports, script, scan_preferences).await
         }
     };
 
