@@ -18,7 +18,7 @@
 #include "../misc/nvt_categories.h" /* for ACT_INIT */
 #include "../misc/pcap_openvas.h"   /* for v6_is_local_ip */
 #include "../misc/plugutils.h"
-#include "../misc/table_driven_lsc.h" /* for make_table_driven_lsc_info_json_str */
+#include "../misc/table_driven_lsc.h" /*for run_table_driven_lsc */
 #include "../misc/user_agent.h"       /* for user_agent_set */
 #include "../nasl/nasl_debug.h"       /* for nasl_*_filename */
 #include "hosts.h"
@@ -44,6 +44,7 @@
 #include <gvm/util/nvticache.h> /* for nvticache_t */
 #include <pthread.h>
 #include <signal.h>
+#include <stdio.h>
 #include <string.h>   /* for strlen() */
 #include <sys/wait.h> /* for waitpid() */
 #include <unistd.h>   /* for close() */
@@ -312,157 +313,55 @@ append_vhost (const char *vhost, const char *source)
   g_info ("%s: add vhost '%s' from '%s'", __func__, vhost, source);
 }
 
-/**
- * @brief Publish the necessary data to start a Table driven LSC scan.
- *
- * If the gather-package-list.nasl plugin was launched, and it generated
- * a valid package list for a supported OS, the table driven LSC scan
- * which is subscribed to the topic will perform a scan an publish the
- * the results to be handle by the sensor/client.
- *
- * @param scan_id     Scan Id.
- * @param kb
- * @param ip_str      IP string of host.
- * @param hostname    Name of host.
- *
- * @return 0 on success, less than 0 on error.
- */
-static int
-run_table_driven_lsc (const char *scan_id, kb_t kb, const char *ip_str,
-                      const char *hostname)
+static void
+call_lsc (struct attack_start_args *args, const char *ip_str)
 {
-  gchar *json_str;
-  gchar *package_list;
-  gchar *os_release;
-  gchar *topic;
-  gchar *payload;
-  gchar *status = NULL;
-  int topic_len;
-  int payload_len;
-  int err = 0;
+  char *package_list = NULL;
+  char *os_release = NULL;
+  kb_t hostkb = NULL;
 
-  // Subscribe to status topic
-  err = mqtt_subscribe ("scanner/status");
-  if (err)
+  hostkb = args->host_kb;
+  /* Get the OS release. TODO: have a list with
+   * supported OS. */
+  os_release = kb_item_get_str (hostkb, "ssh/login/release_notus");
+  /* Get the package list. */
+  package_list = kb_item_get_str (hostkb, "ssh/login/package_list_notus");
+
+  if (run_table_driven_lsc (args->globals->scan_id, ip_str, NULL, package_list,
+                            os_release)
+      < 0)
     {
-      g_warning ("%s: Error starting lsc. Unable to subscribe", __func__);
-      return -1;
+      char buffer[2048];
+      snprintf (buffer, sizeof (buffer),
+                "ERRMSG|||%s||| ||| ||| ||| Unable to "
+                "launch table driven lsc",
+                ip_str);
+      kb_item_push_str_with_main_kb_check (get_main_kb (), "internal/results",
+                                           buffer);
+      g_warning ("%s: Unable to launch table driven LSC", __func__);
     }
-  /* Get the OS release. TODO: have a list with supported OS. */
-
-  os_release = kb_item_get_str (kb, "ssh/login/release_notus");
-  /* Get the package list. Currently only rpm support */
-  package_list = kb_item_get_str (kb, "ssh/login/package_list_notus");
-  if (!os_release || !package_list)
-    return 0;
-
-  json_str = make_table_driven_lsc_info_json_str (scan_id, ip_str, hostname,
-                                                  os_release, package_list);
   g_free (package_list);
   g_free (os_release);
-
-  // Run table driven lsc
-  if (json_str == NULL)
-    return -1;
-
-  g_message ("Running Notus for %s", ip_str);
-  err = mqtt_publish ("scanner/package/cmd/notus", json_str);
-  if (err)
-    {
-      g_warning ("%s: Error publishing message for Notus.", __func__);
-      g_free (json_str);
-      return -1;
-    }
-
-  g_free (json_str);
-
-  // Wait for Notus scanner to start or interrupt
-  while (!status)
-    {
-      err = mqtt_retrieve_message (&topic, &topic_len, &payload, &payload_len,
-                                   60000);
-      if (err == -1 || err == 1)
-        {
-          g_warning ("%s: Unable to retrieve status message from notus. %s",
-                     __func__, err == 1 ? "Timeout after 60 s." : "");
-          return -1;
-        }
-
-      // Get status if it belongs to corresponding scan and host
-      // Else wait for next status message
-      status = get_status_of_table_driven_lsc_from_json (scan_id, ip_str,
-                                                         payload, payload_len);
-
-      g_free (topic);
-      g_free (payload);
-    }
-  // If started wait for it to finish or interrupt
-  if (!g_strcmp0 (status, "running"))
-    {
-      g_debug ("%s: table driven LSC with scan id %s successfully started "
-               "for host %s",
-               __func__, scan_id, ip_str);
-      g_free (status);
-      status = NULL;
-      while (!status)
-        {
-          err = mqtt_retrieve_message (&topic, &topic_len, &payload,
-                                       &payload_len, 60000);
-          if (err == -1)
-            {
-              g_warning ("%s: Unable to retrieve status message from notus.",
-                         __func__);
-              return -1;
-            }
-          if (err == 1)
-            {
-              g_warning ("%s: Unablet to retrieve message. Timeout after 60s.",
-                         __func__);
-              return -1;
-            }
-
-          status = get_status_of_table_driven_lsc_from_json (
-            scan_id, ip_str, payload, payload_len);
-          g_free (topic);
-          g_free (payload);
-        }
-    }
-  else
-    {
-      g_warning ("%s: Unable to start lsc. Got status: %s", __func__, status);
-      g_free (status);
-      return -1;
-    }
-
-  if (g_strcmp0 (status, "finished"))
-    {
-      g_warning (
-        "%s: table driven lsc with scan id %s did not finish successfully "
-        "for host %s. Last status was %s",
-        __func__, scan_id, ip_str, status);
-      err = -1;
-    }
-  else
-    g_debug ("%s: table driven lsc with scan id %s successfully finished "
-             "for host %s",
-             __func__, scan_id, ip_str);
-  g_free (status);
-  return err;
 }
 
-static void
-process_ipc_data (const gchar *result)
+static int
+process_ipc_data (struct attack_start_args *args, const gchar *result)
 {
   ipc_data_t *idata;
+  int ipc_msg_flag = IPC_DT_NO_DATA;
 
   if ((idata = ipc_data_from_json (result, strlen (result))) != NULL)
     {
       switch (ipc_get_data_type_from_data (idata))
         {
         case IPC_DT_ERROR:
+          ipc_msg_flag |= IPC_DT_ERROR;
           g_warning ("%s: Unknown data type.", __func__);
           break;
+        case IPC_DT_NO_DATA:
+          break;
         case IPC_DT_HOSTNAME:
+          ipc_msg_flag |= IPC_DT_HOSTNAME;
           if (ipc_get_hostname_from_data (idata) == NULL)
             g_warning ("%s: ihost data is NULL ignoring new vhost", __func__);
           else
@@ -470,6 +369,7 @@ process_ipc_data (const gchar *result)
                           ipc_get_hostname_source_from_data (idata));
           break;
         case IPC_DT_USER_AGENT:
+          ipc_msg_flag |= IPC_DT_USER_AGENT;
           if (ipc_get_user_agent_from_data (idata) == NULL)
             g_warning ("%s: iuser_agent data is NULL, ignoring new user agent",
                        __func__);
@@ -482,15 +382,40 @@ process_ipc_data (const gchar *result)
               g_free (old_ua);
             }
           break;
+        case IPC_DT_LSC:
+          ipc_msg_flag |= IPC_DT_LSC;
+          set_lsc_flag ();
+          if (!scan_is_stopped () && prefs_get_bool ("table_driven_lsc")
+              && (prefs_get_bool ("mqtt_enabled")
+                  || prefs_get_bool ("openvasd_lsc_enabled")))
+            {
+              struct in6_addr hostip;
+              gchar ip_str[INET6_ADDRSTRLEN];
+
+              if (!ipc_get_lsc_data_ready_flag (idata))
+                {
+                  g_warning ("%s: Unknown data type.", __func__);
+                  ipc_msg_flag |= IPC_DT_ERROR;
+                  break;
+                }
+
+              gvm_host_get_addr6 (args->host, &hostip);
+              addr6_to_str (&hostip, ip_str);
+
+              call_lsc (args, ip_str);
+            }
+          break;
         }
       ipc_data_destroy (&idata);
     }
+  return ipc_msg_flag;
 }
 
-static void
-read_ipc (struct ipc_context *ctx)
+static int
+read_ipc (struct attack_start_args *args, struct ipc_context *ctx)
 {
   char *results;
+  int ipc_msg_flag = IPC_DT_NO_DATA;
 
   while ((results = ipc_retrieve (ctx, IPC_MAIN)) != NULL)
     {
@@ -505,11 +430,12 @@ read_ipc (struct ipc_context *ctx)
             memcpy (message, &results[pos], len);
             pos = j + 1;
             len = 0;
-            process_ipc_data (message);
+            ipc_msg_flag |= process_ipc_data (args, message);
             g_free (message);
           }
     }
   g_free (results);
+  return ipc_msg_flag;
 }
 
 /**
@@ -598,9 +524,11 @@ launch_plugin (struct scan_globals *globals, struct scheduler_plugin *plugin,
     {
       for (int i = 0; i < procs_get_ipc_contexts ()->len; i++)
         {
-          read_ipc (&procs_get_ipc_contexts ()->ctxs[i]);
+          read_ipc (args, &procs_get_ipc_contexts ()->ctxs[i]);
         }
     }
+
+  /* Start the plugin */
   launch_error = 0;
   pid = plugin_launch (globals, plugin, ip, vhosts, args->host_kb,
                        get_main_kb (), nvti, &launch_error);
@@ -751,19 +679,11 @@ attack_host (struct scan_globals *globals, struct in6_addr *ip,
     }
 
   if (!scan_is_stopped () && prefs_get_bool ("table_driven_lsc")
-      && prefs_get_bool ("mqtt_enabled"))
+      && !lsc_has_run ()
+      && (prefs_get_bool ("mqtt_enabled")
+          || prefs_get_bool ("openvasd_lsc_enabled")))
     {
-      if (run_table_driven_lsc (globals->scan_id, args->host_kb, ip_str, NULL))
-        {
-          char buffer[2048];
-          snprintf (
-            buffer, sizeof (buffer),
-            "ERRMSG|||%s||| ||| ||| ||| Unable to launch table driven lsc",
-            ip_str);
-          kb_item_push_str_with_main_kb_check (get_main_kb (),
-                                               "internal/results", buffer);
-          g_warning ("%s: Unable to launch table driven LSC", __func__);
-        }
+      call_lsc (args, ip_str);
     }
 
   pluginlaunch_wait (get_main_kb (), args->host_kb);
@@ -783,6 +703,7 @@ host_died:
   pluginlaunch_stop ();
   plugins_scheduler_free (args->sched);
   host_set_time (get_main_kb (), ip_str, "HOST_END");
+  write_host_stats (args->host_kb, globals->scan_id, ip_str);
 }
 
 /*
@@ -993,22 +914,23 @@ attack_start (struct ipc_context *ipcc, struct attack_start_args *args)
     }
 }
 
-static void
+static int
 apply_hosts_excluded (gvm_hosts_t *hosts)
 {
   const char *exclude_hosts = prefs_get ("exclude_hosts");
-
+  int ret = 0;
   /* Exclude hosts ? */
   if (exclude_hosts)
     {
       /* Exclude hosts, resolving hostnames. */
-      int ret = gvm_hosts_exclude (hosts, exclude_hosts);
+      ret = gvm_hosts_exclude (hosts, exclude_hosts);
 
       if (ret > 0)
         g_message ("exclude_hosts: Skipped %d host(s).", ret);
       if (ret < 0)
         g_message ("exclude_hosts: Error.");
     }
+  return ret;
 }
 
 #ifdef FEATURE_HOSTS_ALLOWED_ONLY
@@ -1242,8 +1164,9 @@ scan_stop_cleanup ()
 
 /**
  * @brief Attack a whole network.
+ * return 0 on successes, -1 if there was a critical error.
  */
-void
+int
 attack_network (struct scan_globals *globals)
 {
   int max_hosts = 0, max_checks;
@@ -1251,7 +1174,6 @@ attack_network (struct scan_globals *globals)
   gvm_host_t *host;
   plugins_scheduler_t sched;
   int fork_retries = 0;
-  GHashTable *files;
   struct timeval then, now;
   gvm_hosts_t *hosts;
   const gchar *port_range;
@@ -1259,6 +1181,7 @@ attack_network (struct scan_globals *globals)
   kb_t arg_host_kb, main_kb;
   GSList *unresolved;
   char buf[96];
+  int error = 0;
 
   check_deprecated_prefs ();
 
@@ -1271,13 +1194,16 @@ attack_network (struct scan_globals *globals)
   gettimeofday (&then, NULL);
 
   if (check_kb_access ())
-    return;
-
+    {
+      error = -1;
+      return error;
+    }
   /* Init and check Target List */
   hostlist = prefs_get ("TARGET");
   if (hostlist == NULL)
     {
-      return;
+      error = -1;
+      return error;
     }
 
   /* Verify the port range is a valid one */
@@ -1293,7 +1219,8 @@ attack_network (struct scan_globals *globals)
                  "Scan terminated.");
       set_scan_status ("finished");
 
-      return;
+      error = -1;
+      return error;
     }
 
   /* Initialize the attack. */
@@ -1304,7 +1231,9 @@ attack_network (struct scan_globals *globals)
   if (!sched)
     {
       g_message ("Couldn't initialize the plugin scheduler");
-      return;
+
+      error = -1;
+      return error;
     }
 
   if (plugins_init_error > 0)
@@ -1336,6 +1265,8 @@ attack_network (struct scan_globals *globals)
                          "HOSTS_COUNT");
       kb_lnk_reset (main_kb);
       g_warning ("Invalid target list. Scan terminated.");
+
+      error = -1;
       goto stop;
     }
 
@@ -1360,19 +1291,27 @@ attack_network (struct scan_globals *globals)
   apply_hosts_allow_deny (hosts);
 #endif
 
+  // Remove the excluded hosts
+  int exc = apply_hosts_excluded (hosts);
+
+  /* Send the excluded hosts count to the client, after removing duplicated and
+   * unresolved hosts.*/
+  sprintf (buf, "%d", exc + already_excluded);
+  connect_main_kb (&main_kb);
+  message_to_client (main_kb, buf, NULL, NULL, "HOSTS_EXCLUDED");
+  kb_lnk_reset (main_kb);
+
   /* Send the hosts count to the client, after removing duplicated and
    * unresolved hosts.*/
-  sprintf (buf, "%d", gvm_hosts_count (hosts) + already_excluded);
+  sprintf (buf, "%d", gvm_hosts_count (hosts));
   connect_main_kb (&main_kb);
   message_to_client (main_kb, buf, NULL, NULL, "HOSTS_COUNT");
   kb_lnk_reset (main_kb);
 
-  // Remove the excluded hosts
-  apply_hosts_excluded (hosts);
-
   host = gvm_hosts_next (hosts);
   if (host == NULL)
     goto stop;
+
   hosts_init (max_hosts);
 
   g_message ("Vulnerability scan %s started: Target has %d hosts: "
@@ -1418,6 +1357,13 @@ attack_network (struct scan_globals *globals)
       alive_hosts_list = gvm_hosts_new (gvm_host_value_str (host));
     }
 
+  if (prefs_get ("report_scripts"))
+    {
+      char *path = g_strdup_printf (
+        "%s/%s-stats.json", prefs_get ("report_scripts"), globals->scan_id);
+      write_script_stats ("{\"hosts\": {", path, 2);
+      g_free (path);
+    }
   /*
    * Start the attack !
    */
@@ -1445,7 +1391,7 @@ attack_network (struct scan_globals *globals)
           if (rc < 0 && rc != -2)
             {
               report_kb_failure (rc);
-              goto scan_stop;
+              goto stop;
             }
           else if (rc == -2)
             {
@@ -1462,7 +1408,7 @@ attack_network (struct scan_globals *globals)
         {
           kb_delete (arg_host_kb);
           g_free (host_str);
-          goto scan_stop;
+          goto stop;
         }
 
       if (scan_is_stopped ())
@@ -1575,12 +1521,6 @@ attack_network (struct scan_globals *globals)
 
   g_debug ("Test complete");
 
-scan_stop:
-  /* Free the memory used by the files uploaded by the user, if any. */
-  files = globals->files_translation;
-  if (files)
-    g_hash_table_destroy (files);
-
 stop:
 
   if (test_alive_hosts_only)
@@ -1614,18 +1554,36 @@ stop:
 
   gettimeofday (&now, NULL);
   if (test_alive_hosts_only)
-    g_message ("Vulnerability scan %s finished in %ld seconds: "
-               "%d alive hosts of %d",
-               globals->scan_id, now.tv_sec - then.tv_sec,
-               gvm_hosts_count (alive_hosts_list), gvm_hosts_count (hosts));
+    {
+      g_message ("Vulnerability scan %s finished in %ld seconds: "
+                 "%d alive hosts of %d",
+                 globals->scan_id, now.tv_sec - then.tv_sec,
+                 gvm_hosts_count (alive_hosts_list), gvm_hosts_count (hosts));
+    }
   else
     g_message ("Vulnerability scan %s finished in %ld seconds: %d hosts",
                globals->scan_id, now.tv_sec - then.tv_sec,
                gvm_hosts_count (hosts));
 
+  if (prefs_get ("report_scripts"))
+    {
+      char *buff =
+        g_strdup_printf ("},\"scan_time\":  {\"start\": %ld, \"stop\": %ld}}",
+                         then.tv_sec, now.tv_sec);
+      char *path = g_strdup_printf (
+        "%s/%s-stats.json", prefs_get ("report_scripts"), globals->scan_id);
+
+      write_script_stats (buff, path, 1);
+
+      g_free (buff);
+      g_free (path);
+    }
+
   gvm_hosts_free (hosts);
   if (alive_hosts_list)
     gvm_hosts_free (alive_hosts_list);
 
   set_scan_status ("finished");
+
+  return error;
 }
